# Pictor Lib

[![Pylint](https://github.com/huangyunict/pictor_lib/actions/workflows/pylint.yml/badge.svg)](https://github.com/huangyunict/pictor_lib/actions/workflows/pylint.yml)
[![Python application](https://github.com/huangyunict/pictor_lib/actions/workflows/python-app.yml/badge.svg)](https://github.com/huangyunict/pictor_lib/actions/workflows/python-app.yml)

Pictor Library provide help classes and functions Python image processing library Pillow.

